'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Output = require('cashlib/lib/Output');

var _Output2 = _interopRequireDefault(_Output);

var _stringfu = require('stringfu');

var _ComponentBase = require('tooey/lib/ComponentBase');

var _ComponentBase2 = _interopRequireDefault(_ComponentBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const VALUE_COLUMN_WIDTH = 15;
class OutputsList extends _ComponentBase2.default {

  constructor(outputs, menu, rowSelection) {
    super();

    const columns = [{
      heading: 'Index',
      width: 8,
      value: (output, index) => index.toString()
    }, {
      heading: 'Value (BCH)',
      width: VALUE_COLUMN_WIDTH,
      value: output => {
        const bch = (output.value / 100000000).toFixed(8);
        return (0, _stringfu.leftPad)(bch, VALUE_COLUMN_WIDTH, ' ');
      }
    }, {
      heading: 'Address',
      width: 40,
      value: output => {
        let addressEncoded = '';
        try {
          const address = output.getAddress(_state2.default.connection.network);
          if (address) {
            addressEncoded = address.toString();
          }
        } catch (err) {
          _app2.default.setWarning(err.message);
          addressEncoded = 'Sorry, not available yet';
        }
        return addressEncoded;
      }
    }, {
      heading: 'Type',
      width: 10,
      value: output => output.scriptType
    }];

    this._list = new _List2.default(_app2.default, columns, outputs, {
      menu,
      rowSelection
    });
  }

  get selectedOutputIndex() {
    return this._list.selectedRowIndex;
  }

  render() {
    // Render outputs list
    this._list.render();
  }

  async handle(key) {
    await this._list.handle(key);
  }
}
exports.default = OutputsList;