'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuForm = require('tooey/lib/MenuForm');

var _MenuForm2 = _interopRequireDefault(_MenuForm);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _MenuOption = require('tooey/lib/MenuOption');

var _MenuOption2 = _interopRequireDefault(_MenuOption);

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _Input = require('cashlib/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _SelectOutput = require('./SelectOutput');

var _SelectOutput2 = _interopRequireDefault(_SelectOutput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fieldIdx = {
  TRANSACTION_ID: 0,
  OUTPUT_INDEX: 1
};

class TransactionAddInput extends _ViewBase2.default {

  constructor() {
    super('Add Input');

    // Form fields
    const fields = [];
    fields[fieldIdx.TRANSACTION_ID] = { label: 'Transaction Id', default: '', type: 'string' };
    fields[fieldIdx.OUTPUT_INDEX] = { label: 'Output index', default: '', type: 'integer' };

    // Menu options
    const menuOptions = [new _MenuOption2.default('O', 'OK', 'Add input with entered details', this.addInput.bind(this)), new _MenuOption2.default('L', 'Lookup Output', 'Lookup output in transaction', this.lookupOutput.bind(this))];

    this._menuForm = new _MenuForm2.default(_app2.default, fields, menuOptions);
  }

  async lookupOutput() {
    try {
      const txId = this._menuForm.fields[fieldIdx.TRANSACTION_ID].input.value;
      if (!txId) {
        _app2.default.setError('Enter Transaction Id to lookup output in.');
      } else {
        const raw = await _state2.default.rpc.request(`getrawtransaction ${txId}`);
        const transaction = _Transaction2.default.deserialize(raw.toString());
        const select = new _SelectOutput2.default(transaction.outputs, this.onLookupSelection.bind(this));
        _app2.default.pushView(select);
      }
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  async onLookupSelection(outputIndex) {
    this._menuForm.fields[fieldIdx.OUTPUT_INDEX].input.value = outputIndex.toString();
    _app2.default.popView();
    this._menuForm.menu.setFirstOptionSelected();
  }

  async addInput() {
    try {
      // app.popView();
      const txId = this._menuForm.fields[fieldIdx.TRANSACTION_ID].input.value;
      const outputIdx = this._menuForm.fields[fieldIdx.OUTPUT_INDEX].input.value;
      if (!txId || !outputIdx) {
        _app2.default.setWarning('Enter Transaction Id and Output Index to continue.');
      } else {
        const input = new _Input2.default(txId, parseInt(outputIdx, 10), new Uint8Array([]));
        _state2.default.transactions.active.addInput(input);
        _app2.default.popView();
      }
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  async handle(key) {
    await this._menuForm.handle(key);
  }

  render() {
    this._menuForm.render();
  }
}
exports.default = TransactionAddInput;